.ext-ol-search {
    position: absolute;
    top: 0.5em;
    left: 2.5em;
}

.ext-ol-autocomplete-results {
    border: 1px solid var(--border-color, #CCC);
    max-height: 200px;
    overflow-y: auto;
    background-color: var(--darkened-bg, #FFF);
    color: var(--body-fg);
    width: 20em;
    position: absolute;
    top: 2.5em;
    left: 2.5em;
}

.ext-ol-autocomplete-results div {
    padding: 8px;
    cursor: pointer;
}

.ext-ol-autocomplete-results div:hover {
    background-color: var(--darkened-bg, #FFF);
}

.ext-ol-hidden {
    display: none;
}